==> catalog-0.0.1.tar.gz: bin/tasks/tasks/catalog_task.dart <==
import 'dart:io';

import 'package:catalog/src/base/serial.dart';
import 'package:catalog/src/builders/built_component.dart';
import 'package:catalog/src/component/component_node.dart';

import '../../catalog_builder/catalog_builder.dart';
import '../../utils/configuration.dart';
import '../base/base_task.dart';

class CatalogTask extends BaseTask {
  @override
  Future<void> work() async {
    var appId = loadId();
    var config = loadConfigFile();

    final page = config['pageFile'] ?? 'catalog_component.dart';
    final pageName = config['pageName'] ?? 'CatalogComponent';
    final pageRoute = config['pageRoute'] ?? 'catalog';
    final prefixValue = config['prefix'] ?? 'preview';

    final dir = Directory('./${config['base']}');
    await dir.create(recursive: true);

    final dirOutPut = Directory('./${config['base']}/${config['output']}');
    await dirOutPut.create(recursive: true);

    final List<FileSystemEntity> entities =
        await dir.list(recursive: true).toList();

    final files = <FileSystemEntity>[];

    for (FileSystemEntity fileSystemEntity in entities) {
      if (fileSystemEntity.path.contains('.$prefixValue.')) {
        files.add(fileSystemEntity);
      }
    }

    var map = <String, BuiltComponent>{};

    for (FileSystemEntity fileSystemEntity in files) {
      final File file = File(fileSystemEntity.path);
      var p = file.path.split(config['base'])[1];
      var package = 'package:$appId$p';
      var className = await findPreviewClassName(file.path);

      if (className == null) {
        print('No class name found ${file.path}');
        continue;
      }
      //print('- Building preview of $className in $package');

      var preview = await previewOnFile(
        config,
        file.path,
      );

      if (preview == null) {
        print('No preview data found ${file.path}');
        continue;
      }

      // print('Preview: ${jsonEncode(preview.toJson())}');

      var outputFolder =
          './${config['base']}/${config['output']}/${preview.path}/';

      var build = await createPage(
        appId,
        config['base'],
        outputFolder,
        p.split('/').last,
        prefixValue,
        preview,
        package,
        className,
      );

      if (build?.preview == null) {
        print('No build for $className');
        continue;
      }
      // print('Built: ${jsonEncode(build!.toJson())}');

      map[build!.preview!.path] = build;
    }

    ComponentNode? node = getNodesFrom(pageRoute, map);

    node = await buildChildrenPages(
      config,
      appId,
      node,
      '',
      pageRoute,
      0,
    );

    if (node == null) {
      return;
    }

    // print(node.toJson().toPrettyString());

    final File assetsConfig = File('./${config['runtimeConfigHolder']}');
    assetsConfig.writeAsStringSync(node.toJson().toPrettyString());

    final File catalogFile =
        File('./${config['base']}/${config['output']}/$page');

    // print(node.routerBuilder);

    var catalogContent = '''
/// AUTOGENERATED FILE. DO NOT EDIT

import 'package:flutter/material.dart';
import 'package:catalog/catalog.dart';
import 'package:go_router/go_router.dart';
${node.imports}

class $pageName extends StatefulWidget {
  static String routeName = '/$pageRoute';
  static GoRoute route = ${node.routerBuilder};
  const $pageName({Key? key}) : super(key: key);

  @override
  ${pageName}State createState() => ${pageName}State();
}

class ${pageName}State extends State<$pageName> {

  TreeController<ComponentNode>? treeController;
  

  @override
  Widget build(BuildContext context) {
    return PreviewScaffold(
      onBackPressed: Catalog().onBackPressed,
      child: FutureBuilder<ComponentNode?>(
          initialData: null,
          future: Catalog().get(context),
          builder: (context, data) {
            if (!data.hasData || data.data == null) {
              return Container();
            }
            final node = data.data as ComponentNode;
            if (treeController == null) {
              treeController = TreeController<ComponentNode>(
                roots: [node],
                childrenProvider: (ComponentNode node) => node.children.values,
              );
              if (treeController!.isTreeCollapsed) {
                treeController!.expandAll();
              }
            }
            return AnimatedTreeView<ComponentNode>(
              treeController: treeController!,
              nodeBuilder:
                  (BuildContext context, TreeEntry<ComponentNode> entry) {
                return InkWell(
                  onTap: () {
                    // _nodePressed(node);
                  },
                  child: TreeIndentation(
                    entry: entry,
                    child: Row(
                      children: [
                        FolderButton(
                          color: Colors.black,
                          isOpen: entry.hasChildren ? entry.isExpanded : null,
                          onPressed: () => _nodePressed(entry),
                        ),
                        Text(
                          entry.node.id,
                          style: const TextStyle(
                            color: Colors.black,
                            fontSize: 16,
                            letterSpacing: .3,
                          ),
                        ),
                      ],
                    ),
                  ),
                );
              },
            );
          }),
    );
  }

  void _nodePressed(TreeEntry<ComponentNode> entry) {
    if (entry.node.children.isEmpty) {
      if (entry.node.builtComponent?.preview?.path != null) {
        context.go(
            '\${$pageName.routeName}/\${entry.node.builtComponent!.preview!.path}');
      }
    } else {
      if (!entry.isExpanded) {
        treeController?.toggleExpansion(entry.node);
      } else {
        treeController?.collapse(entry.node);
      }
    }
  }
}

  '''
        .replaceAll('"""', '\'\'\'')
        .replaceAll(' []', ' const []');

    catalogFile.writeAsStringSync(catalogContent);

    final File file =
        File('./${config['base']}/${config['output']}/process.dart');
    if (file.existsSync()) await file.delete();
  }
}

==> catalog-0.1.0.tar.gz: bin/tasks/tasks/catalog_task.dart <==
import 'dart:io';

import 'package:catalog/src/base/serial.dart';
import 'package:catalog/src/builders/built_component.dart';
import 'package:catalog/src/component/component_node.dart';

import '../../catalog_builder/catalog_builder.dart';
import '../../utils/configuration.dart';
import '../base/base_task.dart';

class CatalogTask extends BaseTask {
  @override
  Future<void> work() async {
    var appId = loadId();
    var config = loadConfigFile();

    final page = config['pageFile'] ?? 'catalog_component.dart';
    final pageName = config['pageName'] ?? 'CatalogComponent';
    final pageRoute = config['pageRoute'] ?? 'catalog';
    final prefixValue = config['prefix'] ?? 'preview';

    final dir = Directory('./${config['base']}');
    await dir.create(recursive: true);

    final dirOutPut = Directory('./${config['base']}/${config['output']}');
    await dirOutPut.create(recursive: true);

    final List<FileSystemEntity> entities =
        await dir.list(recursive: true).toList();

    final files = <FileSystemEntity>[];

    for (FileSystemEntity fileSystemEntity in entities) {
      if (fileSystemEntity.path.contains('.$prefixValue.')) {
        files.add(fileSystemEntity);
      }
    }

    var map = <String, BuiltComponent>{};

    for (FileSystemEntity fileSystemEntity in files) {
      final File file = File(fileSystemEntity.path);
      var p = file.path.split(config['base'])[1];
      var package = 'package:$appId$p';
      var className = await findPreviewClassName(file.path);

      if (className == null) {
        print('No class name found ${file.path}');
        continue;
      }
      //print('- Building preview of $className in $package');

      var preview = await previewOnFile(
        config,
        file.path,
      );

      if (preview == null) {
        print('No preview data found ${file.path}');
        continue;
      }

      // print('Preview: ${jsonEncode(preview.toJson())}');

      var outputFolder =
          './${config['base']}/${config['output']}/${preview.path}/';

      var build = await createPage(
        appId,
        config['base'],
        outputFolder,
        p.split('/').last,
        prefixValue,
        preview,
        package,
        className,
      );

      if (build?.preview == null) {
        print('No build for $className');
        continue;
      }
      // print('Built: ${jsonEncode(build!.toJson())}');

      map[build!.preview!.path] = build;
    }

    ComponentNode? node = getNodesFrom(pageRoute, map);

    node = await buildChildrenPages(
      config,
      appId,
      node,
      '',
      pageRoute,
      0,
    );

    if (node == null) {
      return;
    }

    // print(node.toJson().toPrettyString());

    final File assetsConfig = File('./${config['runtimeConfigHolder']}');
    assetsConfig.writeAsStringSync(node.toJson().toPrettyString());

    final File catalogFile =
        File('./${config['base']}/${config['output']}/$page');

    // print(node.routerBuilder);

    var catalogContent = '''
/// AUTOGENERATED FILE. DO NOT EDIT

import 'package:flutter/material.dart';
import 'package:catalog/catalog.dart';
import 'package:go_router/go_router.dart';
${node.imports}

class $pageName extends StatefulWidget {
  static String routeName = '/$pageRoute';
  static GoRoute route = ${node.routerBuilder};
  const $pageName({super.key});

  @override
  ${pageName}State createState() => ${pageName}State();
}

class ${pageName}State extends State<$pageName> {

  TreeController<ComponentNode>? treeController;
  

  @override
  Widget build(BuildContext context) {
    return PreviewScaffold(
      onBackPressed: Catalog().onBackPressed,
      child: FutureBuilder<ComponentNode?>(
          initialData: null,
          future: Catalog().get(context),
          builder: (context, data) {
            if (!data.hasData || data.data == null) {
              return Container();
            }
            final node = data.data as ComponentNode;
            if (treeController == null) {
              treeController = TreeController<ComponentNode>(
                roots: [node],
                childrenProvider: (ComponentNode node) => node.children.values,
              );
              if (treeController!.isTreeCollapsed) {
                treeController!.expandAll();
              }
            }
            return AnimatedTreeView<ComponentNode>(
              treeController: treeController!,
              nodeBuilder:
                  (BuildContext context, TreeEntry<ComponentNode> entry) {
                return InkWell(
                  onTap: () {
                    // _nodePressed(node);
                  },
                  child: TreeIndentation(
                    entry: entry,
                    child: Row(
                      children: [
                        FolderButton(
                          color: Colors.black,
                          isOpen: entry.hasChildren ? entry.isExpanded : null,
                          onPressed: () => _nodePressed(entry),
                        ),
                        Text(
                          entry.node.id,
                          style: const TextStyle(
                            color: Colors.black,
                            fontSize: 16,
                            letterSpacing: .3,
                          ),
                        ),
                      ],
                    ),
                  ),
                );
              },
            );
          }),
    );
  }

  void _nodePressed(TreeEntry<ComponentNode> entry) {
    if (entry.node.children.isEmpty) {
      if (entry.node.builtComponent?.preview?.path != null) {
        context.go(
            '\${$pageName.routeName}/\${entry.node.builtComponent!.preview!.path}');
      }
    } else {
      if (!entry.isExpanded) {
        treeController?.toggleExpansion(entry.node);
      } else {
        treeController?.collapse(entry.node);
      }
    }
  }
}

  '''
        .replaceAll('"""', '\'\'\'')
        .replaceAll(' []', ' const []');

    catalogFile.writeAsStringSync(catalogContent);

    final File file =
        File('./${config['base']}/${config['output']}/process.dart');
    if (file.existsSync()) await file.delete();
  }
}
